import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class MaterialFreestyleButtonsPanel:
    """ """

    bl_context: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    def poll(self, context):
        """

        :param context:
        """
        ...

class RENDER_MT_lineset_context_menu(bpy_types.Menu, bpy_types._GenericUI):
    """ """

    bl_label: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, _context):
        """

        :param _context:
        """
        ...

    def draw_collapsible(self, context, layout):
        """

        :param context:
        :param layout:
        """
        ...

    def draw_preset(self, _context):
        """

        :param _context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
        add_operator_props,
    ):
        """

        :param searchpaths:
        :param operator:
        :param props_default:
        :param prop_filepath:
        :param filter_ext:
        :param filter_path:
        :param display_name:
        :param add_operator:
        :param add_operator_props:
        """
        ...

    def path_resolve(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class RenderFreestyleButtonsPanel:
    """ """

    bl_context: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    def poll(self, context):
        """

        :param context:
        """
        ...

class ViewLayerFreestyleButtonsPanel:
    """ """

    bl_context: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    def poll(self, context):
        """

        :param context:
        """
        ...

class VIEWLAYER_UL_linesets(bpy_types.UIList, bpy_types._GenericUI):
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw_item(
        self, _context, layout, _data, item, icon, _active_data, _active_propname, index
    ):
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param index:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class MATERIAL_PT_freestyle_line(
    bpy_types.Panel, MaterialFreestyleButtonsPanel, bpy_types._GenericUI
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class RENDER_PT_freestyle(
    bpy_types.Panel, RenderFreestyleButtonsPanel, bpy_types._GenericUI
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle(
    bpy_types.Panel, ViewLayerFreestyleButtonsPanel, bpy_types._GenericUI
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_edge_detection(
    bpy_types.Panel, ViewLayerFreestyleButtonsPanel, bpy_types._GenericUI
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_style_modules(
    bpy_types.Panel, ViewLayerFreestyleButtonsPanel, bpy_types._GenericUI
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class ViewLayerFreestyleEditorButtonsPanel(ViewLayerFreestyleButtonsPanel):
    """ """

    bl_context: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    def poll(self, context):
        """

        :param context:
        """
        ...

class VIEWLAYER_PT_freestyle_lineset(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_edge_type_buttons(self, box, lineset, edge_type):
        """

        :param box:
        :param lineset:
        :param edge_type:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class ViewLayerFreestyleLineStyle(
    ViewLayerFreestyleEditorButtonsPanel, ViewLayerFreestyleButtonsPanel
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    def poll(self, context):
        """

        :param context:
        """
        ...

class VIEWLAYER_PT_freestyle_lineset_collection(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_lineset_edgetype(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_edge_type_buttons(self, box, lineset, edge_type):
        """

        :param box:
        :param lineset:
        :param edge_type:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_lineset_facemarks(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_lineset_visibilty(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_alpha(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_alpha_modifier(self, context, modifier):
        """

        :param context:
        :param modifier:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_color(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_color_modifier(self, context, modifier):
        """

        :param context:
        :param modifier:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_geometry(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_geometry_modifier(self, _context, modifier):
        """

        :param _context:
        :param modifier:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_texture(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_thickness(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_thickness_modifier(self, context, modifier):
        """

        :param context:
        :param modifier:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class ViewLayerFreestyleLinestyleStrokesSubPanel(
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    def poll(self, context):
        """

        :param context:
        """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes_chaining(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLinestyleStrokesSubPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes_dashedline(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLinestyleStrokesSubPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes_selection(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLinestyleStrokesSubPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes_sorting(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLinestyleStrokesSubPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes_splitting(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLinestyleStrokesSubPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class VIEWLAYER_PT_freestyle_linestyle_strokes_splitting_pattern(
    bpy_types.Panel,
    ViewLayerFreestyleEditorButtonsPanel,
    ViewLayerFreestyleLinestyleStrokesSubPanel,
    ViewLayerFreestyleLineStyle,
    ViewLayerFreestyleButtonsPanel,
    bpy_types._GenericUI,
):
    """ """

    COMPAT_ENGINES: typing.Any
    """ """

    bl_context: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_order: typing.Any
    """ """

    bl_parent_id: typing.Any
    """ """

    bl_region_type: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    bl_space_type: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

def draw_modifier_box_error(box, _modifier, message):
    """ """

    ...

def draw_modifier_box_header(box, modifier):
    """ """

    ...

def draw_modifier_color_ramp_common(box, modifier, has_range):
    """ """

    ...

def draw_modifier_common(box, modifier):
    """ """

    ...

def draw_modifier_curve_common(box, modifier, has_range, has_value):
    """ """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

class DataPathBuilder:
    """ """

    data_path: typing.Any
    """ """

    def resolve(self, real_base, rna_update_from_map, fcurve, log):
        """

        :param real_base:
        :param rna_update_from_map:
        :param fcurve:
        :param log:
        """
        ...

def anim_data_actions(anim_data):
    """ """

    ...

def classes_recursive(base_type, clss):
    """ """

    ...

def find_path_new(id_data, data_path, rna_update_from_map, fcurve, log):
    """ """

    ...

def id_iter():
    """ """

    ...

def update_data_paths(rna_update, log):
    """ """

    ...



"""
This module provides access to blenders bmesh data structures.

bmesh.ops.rst
bmesh.types.rst
bmesh.utils.rst
bmesh.geometry.rst

:maxdepth: 1
:caption: Submodules

"""

import typing
import bmesh.types
import bpy.types

from . import geometry
from . import ops
from . import types
from . import utils

GenericType = typing.TypeVar("GenericType")

def from_edit_mesh(mesh: bpy.types.Mesh) -> bmesh.types.BMesh:
    """Return a BMesh from this mesh, currently the mesh must already be in editmode.

    :param mesh: The editmode mesh.
    :type mesh: bpy.types.Mesh
    :return: the BMesh associated with this mesh.
    :rtype: bmesh.types.BMesh
    """

    ...

def new(use_operators: bool = True) -> bmesh.types.BMesh:
    """

    :param use_operators: Support calling operators in `bmesh.ops` (uses some extra memory per vert/edge/face).
    :type use_operators: bool
    :return: Return a new, empty BMesh.
    :rtype: bmesh.types.BMesh
    """

    ...

def update_edit_mesh(
    mesh: bpy.types.Mesh, loop_triangles: bool = True, destructive: bool = True
):
    """Update the mesh after changes to the BMesh in editmode,
    optionally recalculating n-gon tessellation.

        :param mesh: The editmode mesh.
        :type mesh: bpy.types.Mesh
        :param loop_triangles: Option to recalculate n-gon tessellation.
        :type loop_triangles: bool
        :param destructive: Use when geometry has been added or removed.
        :type destructive: bool
    """

    ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def rule_add(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    type: typing.Optional[typing.Union[str, int]] = "GOAL",
):
    """Add a boid rule to the current boid state

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Union[str, int]]
    """

    ...

def rule_del(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Delete current boid rule

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def rule_move_down(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Move boid rule down in the list

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def rule_move_up(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Move boid rule up in the list

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def state_add(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Add a boid state to the particle system

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def state_del(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Delete current boid state

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def state_move_down(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Move boid state down in the list

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def state_move_up(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Move boid state up in the list

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

def do_clear_previews(do_objects, do_collections, do_scenes, do_data_intern):
    """ """

    ...

def do_previews(do_objects, do_collections, do_scenes, do_data_intern):
    """ """

    ...

def ids_nolib(bids):
    """ """

    ...

def ids_nolib_with_preview(bids):
    """ """

    ...

def main():
    """ """

    ...

def rna_backup_gen(data, include_props, exclude_props, root):
    """ """

    ...

def rna_backup_restore(data, backup):
    """ """

    ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class UnifiedPaintPanel:
    """ """

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class VIEW3D_MT_tools_projectpaint_clone(bpy_types.Menu, bpy_types._GenericUI):
    """ """

    bl_label: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_collapsible(self, context, layout):
        """

        :param context:
        :param layout:
        """
        ...

    def draw_preset(self, _context):
        """

        :param _context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
        add_operator_props,
    ):
        """

        :param searchpaths:
        :param operator:
        :param props_default:
        :param prop_filepath:
        :param filter_ext:
        :param filter_path:
        :param display_name:
        :param add_operator:
        :param add_operator_props:
        """
        ...

    def path_resolve(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class BrushPanel(UnifiedPaintPanel):
    """ """

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class BrushSelectPanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class ClonePanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class ColorPalettePanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class DisplayPanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class FalloffPanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class SmoothStrokePanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def draw_header(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class StrokePanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_ui_units_x: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

class TextureMaskPanel(BrushPanel, UnifiedPaintPanel):
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    def draw(self, context):
        """

        :param context:
        """
        ...

    def get_brush_mode(self, context):
        """

        :param context:
        """
        ...

    def paint_settings(self, context):
        """

        :param context:
        """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def prop_unified(
        self,
        layout,
        context,
        brush,
        prop_name,
        unified_name,
        pressure_name,
        icon,
        text,
        slider,
        header,
    ):
        """

        :param layout:
        :param context:
        :param brush:
        :param prop_name:
        :param unified_name:
        :param pressure_name:
        :param icon:
        :param text:
        :param slider:
        :param header:
        """
        ...

    def prop_unified_color(self, parent, context, brush, prop_name, text):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param text:
        """
        ...

    def prop_unified_color_picker(
        self, parent, context, brush, prop_name, value_slider
    ):
        """

        :param parent:
        :param context:
        :param brush:
        :param prop_name:
        :param value_slider:
        """
        ...

def brush_basic__draw_color_selector(context, layout, brush, gp_settings, props):
    """ """

    ...

def brush_basic_gpencil_paint_settings(layout, context, brush, compact):
    """ """

    ...

def brush_basic_gpencil_sculpt_settings(layout, _context, brush, compact):
    """ """

    ...

def brush_basic_gpencil_vertex_settings(layout, _context, brush, compact):
    """ """

    ...

def brush_basic_gpencil_weight_settings(layout, _context, brush, compact):
    """ """

    ...

def brush_basic_grease_pencil_paint_settings(layout, context, brush, compact):
    """ """

    ...

def brush_basic_grease_pencil_weight_settings(layout, context, brush, compact):
    """ """

    ...

def brush_basic_texpaint_settings(layout, context, brush, compact):
    """ """

    ...

def brush_mask_texture_settings(layout, brush):
    """ """

    ...

def brush_settings(layout, context, brush, popover):
    """ """

    ...

def brush_settings_advanced(layout, context, brush, popover):
    """ """

    ...

def brush_shared_settings(layout, context, brush, popover):
    """ """

    ...

def brush_texture_settings(layout, brush, sculpt):
    """ """

    ...

def draw_color_settings(context, layout, brush, color_type):
    """ """

    ...



"""
This module defines properties to extend Blender's internal data. The result of these functions is used to assign properties to classes registered with Blender and can't be used directly.

[NOTE]
All parameters to these functions must be passed as keywords.


--------------------

Custom properties can be added to any subclass of an ID,
Bone and PoseBone.

These properties can be animated, accessed by the user interface and python
like Blender's existing properties.

[WARNING]
Access to these properties might happen in threaded context, on a per-data-block level.
This has to be carefully considered when using accessors or update callbacks.
Typically, these callbacks should not affect any other data that the one owned by their data-block.
When accessing external non-Blender data, thread safety mechanisms should be considered.

```../examples/bpy.props.py```


--------------------

A common use of custom properties is for python based Operator
classes. Test this code by running it in the text editor, or by clicking the
button in the 3D Viewport's Tools panel. The latter will show the properties
in the Redo panel and allow you to change them.

```../examples/bpy.props.1.py```


--------------------

PropertyGroups can be used for collecting custom settings into one value
to avoid many individual settings mixed in together.

```../examples/bpy.props.2.py```


--------------------

Custom properties can be added to any subclass of an ID,
Bone and PoseBone.

```../examples/bpy.props.3.py```


--------------------

It can be useful to perform an action when a property is changed and can be
used to update other properties or synchronize with external data.

All properties define update functions except for CollectionProperty.

[WARNING]
Remember that these callbacks may be executed in threaded context.

[WARNING]
If the property belongs to an Operator, the update callback's first
parameter will be an OperatorProperties instance, rather than an instance
of the operator itself. This means you can't access other internal functions
of the operator, only its other properties.

```../examples/bpy.props.4.py```


--------------------

Getter/setter functions can be used for boolean, int, float, string and enum properties.
If these callbacks are defined the property will not be stored in the ID properties
automatically. Instead, the get and set functions will be called when the property
is respectively read or written from the API.

[WARNING]
Remember that these callbacks may be executed in threaded context.

```../examples/bpy.props.5.py```

[NOTE]
Typically this function doesn't need to be accessed directly.
Instead use del cls.attr



"""

import typing

GenericType = typing.TypeVar("GenericType")

def BoolProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default=False,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new boolean property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_number_items`.
        :type subtype: typing.Optional[str]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def BoolVectorProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default: typing.Optional[typing.Sequence] = (False, False, False),
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    size: typing.Optional[typing.Union[int, typing.Sequence[int]]] = 3,
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new vector boolean property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param default: sequence of booleans the length of size.
        :type default: typing.Optional[typing.Sequence]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_number_array_items`.
        :type subtype: typing.Optional[str]
        :param size: Vector dimensions in [1, 32]. An int sequence can be used to define multi-dimension arrays.
        :type size: typing.Optional[typing.Union[int, typing.Sequence[int]]]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def CollectionProperty(
    type=None,
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
):
    """Returns a new collection property definition.

    :param type: A subclass of `bpy.types.PropertyGroup`.
    :param name: Name used in the user interface.
    :type name: typing.Optional[str]
    :param description: Text used for the tooltip and api documentation.
    :type description: typing.Optional[str]
    :param translation_context: Text used as context to disambiguate translations.
    :type translation_context: typing.Optional[str]
    :param options: Enumerator in `rna_enum_property_flag_items`.
    :type options: typing.Optional[set]
    :param override: Enumerator in `rna_enum_property_override_flag_collection_items`.
    :type override: typing.Optional[set]
    :param tags: Enumerator of tags that are defined by parent class.
    :type tags: typing.Optional[set]
    """

    ...

def EnumProperty(
    items: typing.Optional[
        typing.Union[typing.Iterable[typing.Iterable[str]], typing.Callable]
    ],
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default: typing.Optional[typing.Union[str, set]] = None,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new enumerator property definition.

        :param items: sequence of enum items formatted:
    [(identifier, name, description, icon, number), ...].

    The first three elements of the tuples are mandatory.

    identifier

    The identifier is used for Python access.

    name

    Name for the interface.

    description

    Used for documentation and tooltips.

    icon

    An icon string identifier or integer icon value
    (e.g. returned by `bpy.types.UILayout.icon`)

    number

    Unique value used as the identifier for this item (stored in file data).
    Use when the identifier may need to change. If the ENUM_FLAG option is used,
    the values are bit-masks and should be powers of two.

    When an item only contains 4 items they define (identifier, name, description, number).

    Separators may be added using None instead of a tuple.
    For dynamic values a callback can be passed which returns a list in
    the same format as the static list.
    This function must take 2 arguments (self, context), context may be None.

    There is a known bug with using a callback,
    Python must keep a reference to the strings returned by the callback or Blender
    will misbehave or even crash.
        :type items: typing.Optional[typing.Union[typing.Iterable[typing.Iterable[str]], typing.Callable]]
        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param default: The default value for this enum, a string from the identifiers used in items, or integer matching an item number.
    If the ENUM_FLAG option is used this must be a set of such string identifiers instead.
    WARNING: Strings cannot be specified for dynamic enums
    (i.e. if a callback function is given as items parameter).
        :type default: typing.Optional[typing.Union[str, set]]
        :param options: Enumerator in `rna_enum_property_flag_enum_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def FloatProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default=0.0,
    min: typing.Optional[float] = -3.402823e38,
    max: typing.Optional[float] = 3.402823e38,
    soft_min: typing.Optional[float] = -3.402823e38,
    soft_max: typing.Optional[float] = 3.402823e38,
    step: typing.Optional[int] = 3,
    precision: typing.Optional[int] = 2,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    unit: typing.Optional[str] = "NONE",
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new float (single precision) property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param min: Hard minimum, trying to assign a value below will silently assign this minimum instead.
        :type min: typing.Optional[float]
        :param max: Hard maximum, trying to assign a value above will silently assign this maximum instead.
        :type max: typing.Optional[float]
        :param soft_min: Soft minimum (>= min), user won't be able to drag the widget below this value in the UI.
        :type soft_min: typing.Optional[float]
        :param soft_max: Soft maximum (<= max), user won't be able to drag the widget above this value in the UI.
        :type soft_max: typing.Optional[float]
        :param step: Step of increment/decrement in UI, in [1, 100], defaults to 3 (WARNING: actual value is /100).
        :type step: typing.Optional[int]
        :param precision: Maximum number of decimal digits to display, in [0, 6]. Fraction is automatically hidden for exact integer values of fields with unit 'NONE' or 'TIME' (frame count) and step divisible by 100.
        :type precision: typing.Optional[int]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_number_items`.
        :type subtype: typing.Optional[str]
        :param unit: Enumerator in `rna_enum_property_unit_items`.
        :type unit: typing.Optional[str]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def FloatVectorProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default: typing.Optional[typing.Sequence] = (0.0, 0.0, 0.0),
    min: typing.Optional[float] = None,
    max: typing.Optional[float] = None,
    soft_min: typing.Optional[float] = None,
    soft_max: typing.Optional[float] = None,
    step: typing.Optional[int] = 3,
    precision: typing.Optional[int] = 2,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    unit: typing.Optional[str] = "NONE",
    size: typing.Optional[typing.Union[int, typing.Sequence[int]]] = 3,
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new vector float property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param default: sequence of floats the length of size.
        :type default: typing.Optional[typing.Sequence]
        :param min: Hard minimum, trying to assign a value below will silently assign this minimum instead.
        :type min: typing.Optional[float]
        :param max: Hard maximum, trying to assign a value above will silently assign this maximum instead.
        :type max: typing.Optional[float]
        :param soft_min: Soft minimum (>= min), user won't be able to drag the widget below this value in the UI.
        :type soft_min: typing.Optional[float]
        :param soft_max: Soft maximum (<= max), user won't be able to drag the widget above this value in the UI.
        :type soft_max: typing.Optional[float]
        :param step: Step of increment/decrement in UI, in [1, 100], defaults to 3 (WARNING: actual value is /100).
        :type step: typing.Optional[int]
        :param precision: Maximum number of decimal digits to display, in [0, 6]. Fraction is automatically hidden for exact integer values of fields with unit 'NONE' or 'TIME' (frame count) and step divisible by 100.
        :type precision: typing.Optional[int]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_number_array_items`.
        :type subtype: typing.Optional[str]
        :param unit: Enumerator in `rna_enum_property_unit_items`.
        :type unit: typing.Optional[str]
        :param size: Vector dimensions in [1, 32]. An int sequence can be used to define multi-dimension arrays.
        :type size: typing.Optional[typing.Union[int, typing.Sequence[int]]]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def IntProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default=0,
    min: typing.Optional[int] = None,
    max: typing.Optional[int] = None,
    soft_min: typing.Optional[int] = None,
    soft_max: typing.Optional[int] = None,
    step: typing.Optional[int] = 1,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new int property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param min: Hard minimum, trying to assign a value below will silently assign this minimum instead.
        :type min: typing.Optional[int]
        :param max: Hard maximum, trying to assign a value above will silently assign this maximum instead.
        :type max: typing.Optional[int]
        :param soft_min: Soft minimum (>= min), user won't be able to drag the widget below this value in the UI.
        :type soft_min: typing.Optional[int]
        :param soft_max: Soft maximum (<= max), user won't be able to drag the widget above this value in the UI.
        :type soft_max: typing.Optional[int]
        :param step: Step of increment/decrement in UI, in [1, 100], defaults to 1 (WARNING: unused currently!).
        :type step: typing.Optional[int]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_number_items`.
        :type subtype: typing.Optional[str]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def IntVectorProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default: typing.Optional[typing.Sequence] = (0, 0, 0),
    min: typing.Optional[int] = None,
    max: typing.Optional[int] = None,
    soft_min: typing.Optional[int] = None,
    soft_max: typing.Optional[int] = None,
    step: typing.Optional[int] = 1,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    size: typing.Optional[typing.Union[int, typing.Sequence[int]]] = 3,
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
):
    """Returns a new vector int property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param default: sequence of ints the length of size.
        :type default: typing.Optional[typing.Sequence]
        :param min: Hard minimum, trying to assign a value below will silently assign this minimum instead.
        :type min: typing.Optional[int]
        :param max: Hard maximum, trying to assign a value above will silently assign this maximum instead.
        :type max: typing.Optional[int]
        :param soft_min: Soft minimum (>= min), user won't be able to drag the widget below this value in the UI.
        :type soft_min: typing.Optional[int]
        :param soft_max: Soft maximum (<= max), user won't be able to drag the widget above this value in the UI.
        :type soft_max: typing.Optional[int]
        :param step: Step of increment/decrement in UI, in [1, 100], defaults to 1 (WARNING: unused currently!).
        :type step: typing.Optional[int]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_number_array_items`.
        :type subtype: typing.Optional[str]
        :param size: Vector dimensions in [1, 32]. An int sequence can be used to define multi-dimension arrays.
        :type size: typing.Optional[typing.Union[int, typing.Sequence[int]]]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
    """

    ...

def PointerProperty(
    type=None,
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    poll: typing.Optional[typing.Any] = None,
    update: typing.Optional[typing.Any] = None,
):
    """Returns a new pointer property definition.

        :param type: A subclass of `bpy.types.PropertyGroup` or `bpy.types.ID`.
        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param poll: function to be called to determine whether an item is valid for this property.
    The function must take 2 values (self, object) and return Bool.
        :type poll: typing.Optional[typing.Any]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
    """

    ...

def RemoveProperty(cls: typing.Optional[typing.Any], attr: typing.Optional[str]):
    """Removes a dynamically defined property.

    :param cls: The class containing the property (must be a positional argument).
    :type cls: typing.Optional[typing.Any]
    :param attr: Property name (must be passed as a keyword).
    :type attr: typing.Optional[str]
    """

    ...

def StringProperty(
    name: typing.Optional[str] = "",
    description: typing.Optional[str] = "",
    translation_context: typing.Optional[str] = "*",
    default: typing.Optional[str] = "",
    maxlen: typing.Optional[int] = 0,
    options: typing.Optional[set] = {'"ANIMATABLE"'},
    override: typing.Optional[set] = None(),
    tags: typing.Optional[set] = None(),
    subtype: typing.Optional[str] = "NONE",
    update: typing.Optional[typing.Any] = None,
    get: typing.Optional[typing.Any] = None,
    set: typing.Optional[typing.Any] = None,
    search: typing.Optional[typing.Any] = None,
    search_options: typing.Optional[set] = {'"SUGGESTION"'},
):
    """Returns a new string property definition.

        :param name: Name used in the user interface.
        :type name: typing.Optional[str]
        :param description: Text used for the tooltip and api documentation.
        :type description: typing.Optional[str]
        :param translation_context: Text used as context to disambiguate translations.
        :type translation_context: typing.Optional[str]
        :param default: initializer string.
        :type default: typing.Optional[str]
        :param maxlen: maximum length of the string.
        :type maxlen: typing.Optional[int]
        :param options: Enumerator in `rna_enum_property_flag_items`.
        :type options: typing.Optional[set]
        :param override: Enumerator in `rna_enum_property_override_flag_items`.
        :type override: typing.Optional[set]
        :param tags: Enumerator of tags that are defined by parent class.
        :type tags: typing.Optional[set]
        :param subtype: Enumerator in `rna_enum_property_subtype_string_items`.
        :type subtype: typing.Optional[str]
        :param update: Function to be called when this value is modified,
    This function must take 2 values (self, context) and return None.
    Warning there are no safety checks to avoid infinite recursion.
        :type update: typing.Optional[typing.Any]
        :param get: Function to be called when this value is 'read',
    This function must take 1 value (self) and return the value of the property.
        :type get: typing.Optional[typing.Any]
        :param set: Function to be called when this value is 'written',
    This function must take 2 values (self, value) and return None.
        :type set: typing.Optional[typing.Any]
        :param search: Function to be called to show candidates for this string (shown in the UI).
    This function must take 3 values (self, context, edit_text)
    and return a sequence, iterator or generator where each item must be:

    A single string (representing a candidate to display).

    A tuple-pair of strings, where the first is a candidate and the second
    is additional information about the candidate.
        :type search: typing.Optional[typing.Any]
        :param search_options: Set of strings in:

    'SORT' sorts the resulting items.

    'SUGGESTION' lets the user enter values not found in search candidates.
    WARNING disabling this flag causes the search callback to run on redraw,
    so only disable this flag if it's not likely to cause performance issues.
        :type search_options: typing.Optional[set]
    """

    ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class NODE_MT_category_layout(bpy_types.Menu, bpy_types._GenericUI):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def append(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def draw(self, _context):
        """

        :param _context:
        """
        ...

    def draw_collapsible(self, context, layout):
        """

        :param context:
        :param layout:
        """
        ...

    def draw_preset(self, _context):
        """

        :param _context:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_extended(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_menu(
        self,
        searchpaths,
        operator,
        props_default,
        prop_filepath,
        filter_ext,
        filter_path,
        display_name,
        add_operator,
        add_operator_props,
    ):
        """

        :param searchpaths:
        :param operator:
        :param props_default:
        :param prop_filepath:
        :param filter_ext:
        :param filter_path:
        :param display_name:
        :param add_operator:
        :param add_operator_props:
        """
        ...

    def path_resolve(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def prepend(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def remove(self, draw_func):
        """

        :param draw_func:
        """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

def add_node_type(layout, node_type, label, poll, search_weight):
    """ """

    ...

def add_repeat_zone(layout, label):
    """ """

    ...

def add_simulation_zone(layout, label):
    """ """

    ...

def draw_assets_for_catalog(layout, catalog_path):
    """ """

    ...

def draw_node_group_add_menu(context, layout):
    """ """

    ...

def draw_root_assets(layout):
    """ """

    ...



"""
BVH tree structures for proximity searches and ray casts on geometry.

"""

import typing
import bmesh.types
import bpy.types
import mathutils

GenericType = typing.TypeVar("GenericType")

class BVHTree:
    """ """

    @classmethod
    def FromBMesh(cls, bmesh: bmesh.types.BMesh, epsilon: float = 0.0):
        """BVH tree based on `BMesh` data.

        :param bmesh: BMesh data.
        :type bmesh: bmesh.types.BMesh
        :param epsilon: Increase the threshold for detecting overlap and raycast hits.
        :type epsilon: float
        """
        ...

    @classmethod
    def FromObject(
        cls,
        object: bpy.types.Object,
        depsgraph: bpy.types.Depsgraph,
        deform: bool = True,
        render=False,
        cage: bool = False,
        epsilon: float = 0.0,
    ):
        """BVH tree based on `Object` data.

        :param object: Object data.
        :type object: bpy.types.Object
        :param depsgraph: Depsgraph to use for evaluating the mesh.
        :type depsgraph: bpy.types.Depsgraph
        :param deform: Use mesh with deformations.
        :type deform: bool
        :param render:
        :param cage: Use modifiers cage.
        :type cage: bool
        :param epsilon: Increase the threshold for detecting overlap and raycast hits.
        :type epsilon: float
        """
        ...

    @classmethod
    def FromPolygons(
        cls, vertices, polygons, all_triangles: bool = False, epsilon: float = 0.0
    ):
        """BVH tree constructed geometry passed in as arguments.

        :param vertices: float triplets each representing (x, y, z)
        :param polygons: Sequence of polyugons, each containing indices to the vertices argument.
        :param all_triangles: Use when all polygons are triangles for more efficient conversion.
        :type all_triangles: bool
        :param epsilon: Increase the threshold for detecting overlap and raycast hits.
        :type epsilon: float
        """
        ...

    def find_nearest(self, origin, distance: float = 1.84467e19) -> tuple:
        """Find the nearest element (typically face index) to a point.

                :param origin:
                :param distance: Maximum distance threshold.
                :type distance: float
                :return: Returns a tuple
        (`Vector` location, `Vector` normal, int index, float distance),
        Values will all be None if no hit is found.
                :rtype: tuple
        """
        ...

    def find_nearest_range(self, origin, distance: float = 1.84467e19) -> list:
        """Find the nearest elements (typically face index) to a point in the distance range.

                :param origin:
                :param distance: Maximum distance threshold.
                :type distance: float
                :return: Returns a list of tuples
        (`Vector` location, `Vector` normal, int index, float distance),
                :rtype: list
        """
        ...

    def overlap(self, other_tree: BVHTree) -> list:
        """Find overlapping indices between 2 trees.

        :param other_tree: Other tree to perform overlap test on.
        :type other_tree: BVHTree
        :return: Returns a list of unique index pairs,      the first index referencing this tree, the second referencing the other_tree.
        :rtype: list
        """
        ...

    def ray_cast(
        self,
        origin: typing.Union[typing.Sequence[float], mathutils.Vector],
        direction: typing.Union[typing.Sequence[float], mathutils.Vector],
        distance: float = None,
    ) -> tuple:
        """Cast a ray onto the mesh.

                :param origin: Start location of the ray in object space.
                :type origin: typing.Union[typing.Sequence[float], mathutils.Vector]
                :param direction: Direction of the ray in object space.
                :type direction: typing.Union[typing.Sequence[float], mathutils.Vector]
                :param distance: Maximum distance threshold.
                :type distance: float
                :return: Returns a tuple
        (`Vector` location, `Vector` normal, int index, float distance),
        Values will all be None if no hit is found.
                :rtype: tuple
        """
        ...

    def __init__(self, size):
        """

        :param size:
        """
        ...
